@@ -2,7 +2,7 @@
   am <- adjacencyMatrix(g)
   am[lower.tri(am)]<-0
   edges <- apply(am,1,function(x){
-    which(x==1)
+    which(x!=0)
   })
   return(edges)
 }
