@@ -5,8 +5,8 @@ getLargestSubgraph <- function(g){
   }
   cc.g <- connectedComp(g)
   cclens.g <- sapply(cc.g, length)
-  print("Subgraph distribution:")
-  print(table(cclens.g))
+  #print("Subgraph distribution:")
+  #print(table(cclens.g))
   ord.g <- order(cclens.g, decreasing=T)
   return(subGraph(cc.g[[ord.g[1]]], g))
 }
